import {
  findProjectRoot
} from "../chunk-TGNRM6YP.js";

// src/config/config.ts
import { readFileSync, writeFileSync } from "node:fs";
import { join } from "node:path";
import dotenv from "dotenv";
import { lilconfigSync } from "lilconfig";
import { merge } from "ts-deepmerge";
import { z } from "zod";
var ApplicationConfigSchema = z.object({
  application: z.object({
    id: z.string(),
    displayName: z.string()
  }),
  portalGql: z.string().url().optional(),
  portalRest: z.string().url().optional(),
  thegraphGql: z.string().url().optional(),
  hasuraGql: z.string().url().optional(),
  nodeJsonRpc: z.string().url().optional()
});
var ConfigSchema = z.object({
  framework: z.string(),
  instance: z.string().url(),
  workspace: z.object({
    id: z.string(),
    displayName: z.string()
  }),
  childWorkspace: z.object({
    id: z.string(),
    displayName: z.string()
  }).optional(),
  defaultApplication: z.object({
    id: z.string(),
    displayName: z.string()
  }),
  applications: z.record(z.string(), ApplicationConfigSchema).optional()
});
var ConfigEnvSchema = ConfigSchema.extend({
  pat: z.string(),
  appUrl: z.string().url().optional(),
  hasuraAdminSecret: z.string().optional(),
  sessionSecret: z.string().min(32).optional()
});
var EnvSchema = z.object({
  SETTLEMINT_PAT_TOKEN: z.string(),
  SETTLEMINT_HASURA_GQL_ADMIN_SECRET: z.string().optional(),
  NEXT_PUBLIC_SETTLEMINT_APP_URL: z.string().url().optional(),
  SETTLEMINT_SESSION_SECRET: z.string().min(32).optional()
});
var ApplicationConfigEnvSchema = ApplicationConfigSchema.extend({
  pat: z.string(),
  appUrl: z.string().url().optional(),
  hasuraAdminSecret: z.string().optional()
});
function config() {
  const config2 = parseConfig();
  if (!config2) {
    return void 0;
  }
  return ConfigEnvSchema.parse({
    ...config2,
    pat: process.env.SETTLEMINT_PAT_TOKEN,
    appUrl: process.env.NEXT_PUBLIC_SETTLEMINT_APP_URL,
    hasuraAdminSecret: process.env.SETTLEMINT_HASURA_GQL_ADMIN_SECRET,
    authSecret: process.env.SETTLEMINT_AUTH_SECRET,
    sessionSecret: process.env.SETTLEMINT_SESSION_SECRET
  });
}
function parseConfig() {
  const explorer = lilconfigSync("settlemint");
  const result = explorer.search();
  if (!result) {
    return void 0;
  }
  return ConfigSchema.parse(result.config);
}
async function createConfig(config2) {
  const defaultConfig = {};
  const preConfiguredConfig = merge(defaultConfig, config2);
  const existingConfig = await parseConfig();
  const mergedConfig = existingConfig ? merge(existingConfig, preConfiguredConfig) : preConfiguredConfig;
  const validatedMergedConfig = ConfigSchema.parse(mergedConfig);
  const projectRoot = findProjectRoot(process.cwd());
  const configPath = join(projectRoot, ".settlemintrc.json");
  writeFileSync(configPath, JSON.stringify(validatedMergedConfig, null, 2));
}
var escapeNewlines = (str) => str.replace(/\n/g, "\\n");
var format = (key, value) => `${key}=${escapeNewlines(value)}`;
async function createEnv(env) {
  const projectRoot = findProjectRoot(process.cwd());
  const envPath = join(projectRoot, ".env.local");
  let dotEnv = {};
  try {
    dotEnv = dotenv.parse(readFileSync(envPath, "utf-8"));
  } catch (e) {
  }
  const mergedEnv = merge(dotEnv, env);
  const validatedMergedEnv = EnvSchema.parse(mergedEnv);
  const contents = Object.entries(validatedMergedEnv).filter(([_, value]) => value !== void 0).map(([key, value]) => format(key, value)).join("\n");
  writeFileSync(envPath, contents);
  dotenv.config({
    path: [".env.local", ".env"],
    override: true
  });
}
function activeConfig() {
  const cfg = config();
  if (!cfg) {
    console.warn("No configuration found, please run settlemint connect");
    return void 0;
  }
  const applications = cfg.applications ?? {};
  const env = process.env.SETTLEMINT_APPLICATION ?? cfg?.defaultApplication.id;
  if (!env || Object.keys(applications).length === 0) {
    throw new Error(
      "No environment found, either set SETTLEMINT_APPLICATION or define a default environment in your .settlemintrc.json file"
    );
  }
  const envConf = applications[env];
  if (!envConf) {
    throw new Error(`No application found for ${env}, please run \`settlemint connect\``);
  }
  return ApplicationConfigEnvSchema.parse({
    ...envConf,
    pat: cfg.pat,
    appUrl: cfg.appUrl,
    hasuraAdminSecret: cfg.hasuraAdminSecret
  });
}
export {
  ApplicationConfigEnvSchema,
  activeConfig,
  config,
  createConfig,
  createEnv
};
//# sourceMappingURL=config.js.map